@@ -1,6 +1,6 @@
 getGIC <-
 function(term1, term2){
-	if(!exists("DOSimEnv")) initialize()	
+	if(!exists("DOSimEnv")) initialize_DOSimEnv()	
 	if(term1 == term2){
 		return(1)
 	}
